@@ -6,7 +6,7 @@ use syntax 'each_on_array'; # to support perl < 5.12
 use warnings;
 use Log::Any '$log';
 
-our $VERSION = '1.25'; # VERSION
+our $VERSION = '1.26'; # VERSION
 
 our %SPEC;
 
@@ -103,7 +103,7 @@ Data::Unixish::sort - Sort items
 
 =head1 VERSION
 
-version 1.25
+version 1.26
 
 =head1 SYNOPSIS
 
@@ -121,17 +121,6 @@ In command line:
  b
  c
 
-=head1 FUNCTIONS
-
-
-=head2 sort() -> [status, msg, result, meta]
-
-No arguments.
-
-Return value:
-
-Returns an enveloped result (an array). First element (status) is an integer containing HTTP status code (200 means OK, 4xx caller error, 5xx function error). Second element (msg) is a string containing error message, or 'OK' if status is 200. Third element (result) is optional, the actual result. Fourth element (meta) is called result metadata and is optional, a hash that contains extra information.
-
 =head1 AUTHOR
 
 Steven Haryanto <stevenharyanto@gmail.com>
@@ -143,5 +132,52 @@ This software is copyright (c) 2013 by Steven Haryanto.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 DESCRIPTION
+
+
+This module has L<Rinci> metadata.
+
+=head1 FUNCTIONS
+
+
+None are exported by default, but they are exportable.
+
+=head2 sort(%args) -> [status, msg, result, meta]
+
+Sort items.
+
+By default sort ascibetically, unless C<numeric> is set to true to sort
+numerically.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<ci> => I<bool> (default: 0)
+
+Whether to ignore case.
+
+=item * B<in> => I<any>
+
+=item * B<numeric> => I<bool> (default: 0)
+
+Whether to sort numerically.
+
+=item * B<out> => I<any>
+
+=item * B<random> => I<bool> (default: 0)
+
+Whether to sort by random.
+
+=item * B<reverse> => I<bool> (default: 0)
+
+Whether to reverse sort result.
+
+=back
+
+Return value:
+
+Returns an enveloped result (an array). First element (status) is an integer containing HTTP status code (200 means OK, 4xx caller error, 5xx function error). Second element (msg) is a string containing error message, or 'OK' if status is 200. Third element (result) is optional, the actual result. Fourth element (meta) is called result metadata and is optional, a hash that contains extra information.
+
 =cut
 
