@@ -6,7 +6,7 @@ use syntax 'each_on_array'; # to support perl < 5.12
 use warnings;
 #use Log::Any '$log';
 
-our $VERSION = '1.25'; # VERSION
+our $VERSION = '1.26'; # VERSION
 
 our %SPEC;
 
@@ -62,7 +62,7 @@ Data::Unixish::trim - Strip whitespace at the beginning and end of each line of
 
 =head1 VERSION
 
-version 1.25
+version 1.26
 
 =head1 SYNOPSIS
 
@@ -71,7 +71,7 @@ In Perl:
  use Data::Unixish::trim;
  my $in  = ["x", "   a   ", "  b  \n   c  \n", undef, [" d "]];
  my $out = [];
- Data::Unixish::ltrim::ltrim(in=>$in, out=>$out);
+ Data::Unixish::trim::trim(in=>$in, out=>$out);
  # $out = ["x", "a", "b\nc\n", undef, [" d "]]
 
 In command line:
@@ -80,17 +80,6 @@ In command line:
  x
  a
 
-=head1 FUNCTIONS
-
-
-=head2 trim() -> [status, msg, result, meta]
-
-No arguments.
-
-Return value:
-
-Returns an enveloped result (an array). First element (status) is an integer containing HTTP status code (200 means OK, 4xx caller error, 5xx function error). Second element (msg) is a string containing error message, or 'OK' if status is 200. Third element (result) is optional, the actual result. Fourth element (meta) is called result metadata and is optional, a hash that contains extra information.
-
 =head1 AUTHOR
 
 Steven Haryanto <stevenharyanto@gmail.com>
@@ -102,5 +91,37 @@ This software is copyright (c) 2013 by Steven Haryanto.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 DESCRIPTION
+
+
+This module has L<Rinci> metadata.
+
+=head1 FUNCTIONS
+
+
+None are exported by default, but they are exportable.
+
+=head2 trim(%args) -> [status, msg, result, meta]
+
+Strip whitespace at the beginning and end of each line of text.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<in> => I<any>
+
+=item * B<out> => I<any>
+
+=item * B<strip_newline> => I<bool> (default: 0)
+
+Whether to strip newlines at the beginning and end of text.
+
+=back
+
+Return value:
+
+Returns an enveloped result (an array). First element (status) is an integer containing HTTP status code (200 means OK, 4xx caller error, 5xx function error). Second element (msg) is a string containing error message, or 'OK' if status is 200. Third element (result) is optional, the actual result. Fourth element (meta) is called result metadata and is optional, a hash that contains extra information.
+
 =cut
 
