@@ -8,7 +8,7 @@ use warnings;
 
 use Text::Wrap ();
 
-our $VERSION = '1.25'; # VERSION
+our $VERSION = '1.26'; # VERSION
 
 our %SPEC;
 
@@ -64,7 +64,7 @@ Data::Unixish::wrap - Wrap text
 
 =head1 VERSION
 
-version 1.25
+version 1.26
 
 =head1 SYNOPSIS
 
@@ -82,17 +82,6 @@ In command line:
  xxxx xxxx xxxx xxxx
  xxxx
 
-=head1 FUNCTIONS
-
-
-=head2 wrap() -> [status, msg, result, meta]
-
-No arguments.
-
-Return value:
-
-Returns an enveloped result (an array). First element (status) is an integer containing HTTP status code (200 means OK, 4xx caller error, 5xx function error). Second element (msg) is a string containing error message, or 'OK' if status is 200. Third element (result) is optional, the actual result. Fourth element (meta) is called result metadata and is optional, a hash that contains extra information.
-
 =head1 AUTHOR
 
 Steven Haryanto <stevenharyanto@gmail.com>
@@ -104,5 +93,39 @@ This software is copyright (c) 2013 by Steven Haryanto.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 DESCRIPTION
+
+
+This module has L<Rinci> metadata.
+
+=head1 FUNCTIONS
+
+
+None are exported by default, but they are exportable.
+
+=head2 wrap(%args) -> [status, msg, result, meta]
+
+Wrap text.
+
+Currently implemented using Text::Wrap standard Perl module.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<columns> => I<int> (default: 80)
+
+Target column width.
+
+=item * B<in> => I<any>
+
+=item * B<out> => I<any>
+
+=back
+
+Return value:
+
+Returns an enveloped result (an array). First element (status) is an integer containing HTTP status code (200 means OK, 4xx caller error, 5xx function error). Second element (msg) is a string containing error message, or 'OK' if status is 200. Third element (result) is optional, the actual result. Fourth element (meta) is called result metadata and is optional, a hash that contains extra information.
+
 =cut
 
